# Aibou

## Quickstart

``` bash
pip install aibou
python -m aibou
```

## Linux

``` bash
# keyboard module requires root
sudo su
pip install aibou
python -m aibou
```

## Info

Authored by [Jacob Krol](https://github.com/jakekrol)

### Developer timeline

- Core game development: Winter break of 2022-2023
- Develop and publish python package: Winter break of 2023-2024
